@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 require XSLoader;
 XSLoader::load('Doubly', $VERSION);
@@ -19,7 +19,7 @@ Doubly - The great new Doubly!
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
@@ -29,10 +29,10 @@ Quick summary of what the module does.
 
 Perhaps a little code snippet.
 
-    	use Doubly;
+	use Doubly;
+
+	my $foo = Doubly->new(100);
 
-    	my $foo = Doubly->new(100);
-    
 	$foo->add(200);
 	$foo->add(300);
 
@@ -40,27 +40,9 @@ Perhaps a little code snippet.
 	$foo->next->data; # 200 
 	$foo->next->next->data; 300
 
-=head1 EXPORT
-
-A list of functions that can be exported.  You can delete this section
-if you don't export anything, such as for a purely object-oriented module.
 
 =head1 SUBROUTINES/METHODS
 
-=head2 function1
-
-=cut
-
-sub function1 {
-}
-
-=head2 function2
-
-=cut
-
-sub function2 {
-}
-
 =head1 AUTHOR
 
 LNATION, C<< <email at lnation.org> >>
